datastructuretools.OrdinalConstant
==================================

.. inheritance-diagram:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__eq__

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ge__

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__gt__

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__le__

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__lt__

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__repr__
